| Title: | Shiny Application for 'FossilSim' |
|---|---|
| Description: | A shiny application based on 'FossilSim'. Used for simulating tree, taxonomic and fossil data under mechanistic models of speciation, preservation and sampling. |
| Authors: | Titouan Chambe [aut], Joelle Barido-Sottani [aut, cre, cph], Rachel Warnock [aut, cph] |
| Maintainer: | Joelle Barido-Sottani <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 1.1.2 |
| Built: | 2026-05-27 06:55:04 UTC |
| Source: | https://github.com/cran/FossilSimShiny |
This the function used to launch the shiny app.
launchFossilSimShiny(inbrowser = TRUE)launchFossilSimShiny(inbrowser = TRUE)
inbrowser |
Launch the app inside the system's default browser or not. |
No return value, called for side effects.