Welcome to ClientVPS Mirrors

Help for package FossilSimShiny
Title: Shiny Application for 'FossilSim'
Version: 1.1.2
Description: A shiny application based on 'FossilSim'. Used for simulating tree, taxonomic and fossil data under mechanistic models of speciation, preservation and sampling.
License: GPL (≥ 3)
Encoding: UTF-8
RoxygenNote: 7.1.2
Imports: shiny (≥ 1.7.1), shinyjs, FossilSim, TreeSim
Suggests: knitr, rmarkdown, spelling
VignetteBuilder: knitr
Language: en-US
NeedsCompilation: no
Packaged: 2024-04-29 11:24:28 UTC; barid
Author: Titouan Chambe [aut], Joelle Barido-Sottani [aut, cre, cph], Rachel Warnock [aut, cph]
Maintainer: Joelle Barido-Sottani <joelle.barido-sottani@m4x.org>
Repository: CRAN
Date/Publication: 2024-04-29 11:40:02 UTC

Run the app in a web browser

Description

This the function used to launch the shiny app.

Usage

launchFossilSimShiny(inbrowser = TRUE)

Arguments

inbrowser

Launch the app inside the system's default browser or not.

Value

No return value, called for side effects.

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.